Index: /trunk/src/org/openstreetmap/josm/gui/layer/GpxLayer.java
===================================================================
--- /trunk/src/org/openstreetmap/josm/gui/layer/GpxLayer.java	(revision 16862)
+++ /trunk/src/org/openstreetmap/josm/gui/layer/GpxLayer.java	(revision 16863)
@@ -278,5 +278,5 @@
         List<Action> expert = Arrays.asList(
                 new CombineTracksToSegmentedTrackAction(this),
-                new SplitTrackSegementsToTracksAction(this),
+                new SplitTrackSegmentsToTracksAction(this),
                 new SplitTracksToLayersAction(this));
 
@@ -481,12 +481,12 @@
      * @since 13210
      */
-    public static class SplitTrackSegementsToTracksAction extends AbstractAction {
+    public static class SplitTrackSegmentsToTracksAction extends AbstractAction {
         private final transient GpxLayer layer;
 
         /**
          * Create a new SplitTrackSegementsToTracksAction
          * @param layer The layer with the data to work on.
          */
-        public SplitTrackSegementsToTracksAction(GpxLayer layer) {
+        public SplitTrackSegmentsToTracksAction(GpxLayer layer) {
             // FIXME: icon missing, create a new icon for this action
             //new ImageProvider(..."gpx_segmented_track_to_tracks").getResource().attachImageIcon(this, true);
@@ -518,5 +518,5 @@
 
         /**
          * Create a new SplitTrackSegementsToTracksAction
          * @param layer The layer with the data to work on.
          */
@@ -481,12 +481,12 @@
 
         /**
-         * Create a new SplitTrackSegementsToTracksAction
+         * Create a new SplitTrackSegmentsToTracksAction
          * @param layer The layer with the data to work on.
          */
@@ -518,5 +518,5 @@
 
         /**
-         * Create a new SplitTrackSegementsToTracksAction
+         * Create a new SplitTrackSegmentsToTracksAction
          * @param layer The layer with the data to work on.
          */
